@@ -21,7 +21,7 @@ var AccountsMonitor = class {
 
         if (!this._app.isTestInstance) {
             this._app.connect('prepare-shutdown',
-                              this._onPrepareShutdown.bind(this));
+                this._onPrepareShutdown.bind(this));
         }
 
         let factory = new ClientFactory();
@@ -212,26 +212,22 @@ class ClientFactory extends Polari.ClientFactory {
 
 const PolariAccount = GObject.registerClass({
     Properties: {
-        predefined: GObject.ParamSpec.boolean('predefined',
-                                              'predefined',
-                                              'predefined',
-                                              GObject.ParamFlags.READABLE,
-                                              false),
-        reachable: GObject.ParamSpec.boolean('reachable',
-                                             'reachable',
-                                             'reachable',
-                                             GObject.ParamFlags.READABLE,
-                                             false),
-        visible: GObject.ParamSpec.boolean('visible',
-                                           'visible',
-                                           'visible',
-                                           GObject.ParamFlags.READWRITE,
-                                           true),
-        settings: GObject.ParamSpec.object('settings',
-                                           'settings',
-                                           'settings',
-                                           GObject.ParamFlags.READABLE,
-                                           Gio.Settings.$gtype)
+        predefined: GObject.ParamSpec.boolean(
+            'predefined', 'predefined', 'predefined',
+            GObject.ParamFlags.READABLE,
+            false),
+        reachable: GObject.ParamSpec.boolean(
+            'reachable', 'reachable', 'reachable',
+            GObject.ParamFlags.READABLE,
+            false),
+        visible: GObject.ParamSpec.boolean(
+            'visible', 'visible', 'visible',
+            GObject.ParamFlags.READWRITE,
+            true),
+        settings: GObject.ParamSpec.object(
+            'settings', 'settings', 'settings',
+            GObject.ParamFlags.READABLE,
+            Gio.Settings.$gtype)
     }
 }, class PolariAccount extends Tp.Account {
     _init(params) {
