@@ -207,6 +207,9 @@ var Application = GObject.registerClass({
             activate: this._onLeaveCurrentRoom.bind(this),
             create_hook: (a) => a.enabled = false,
             accels: ['<Primary>w']
+        }, {
+            name: 'reconnect-room',
+            parameter_type: GLib.VariantType.new('s')
         }, {
             name: 'authenticate-account',
             parameter_type: GLib.VariantType.new('(os)')
