@@ -185,6 +185,9 @@ class TelepathyClient extends Tp.BaseClient {
         }, {
             name: 'leave-room',
             handler: this._onLeaveActivated.bind(this)
+        }, {
+            name: 'reconnect-room',
+            handler: this._onReconnectRoomActivated.bind(this)
         }, {
             name: 'connect-account',
             handler: this._onConnectAccountActivated.bind(this)
@@ -321,10 +324,15 @@ class TelepathyClient extends Tp.BaseClient {
         req.ensure_and_observe_channel_async(preferredHandler, cancellable,
             (o, res) => {
                 let channel = null;
+                let room = this._roomManager.lookupRoom(roomId);
                 try {
                     channel = req.ensure_and_observe_channel_finish(res);
+                    room.channel_error = '';
                 } catch (e) {
                     debug(`Failed to ensure channel: ${e.message}`);
+
+                    if (room)
+                        room.channel_error = Tp.error_get_dbus_name(e.code);
                 }
 
                 if (callback)
@@ -505,6 +513,12 @@ class TelepathyClient extends Tp.BaseClient {
         this._app.withdraw_notification(this._getIdentifyNotificationID(accountPath));
     }
 
+    _onReconnectRoomActivated(action, parameter) {
+        let roomId = parameter.deep_unpack();
+        let room = this._roomManager.lookupRoom(roomId);
+        this._connectRoom(room);
+    }
+
     _isAuthChannel(channel) {
         let channelType = channel.get_channel_type();
         return channelType == Tp.IFACE_CHANNEL_TYPE_SERVER_AUTHENTICATION;
